@@ -1,6 +1,6 @@
 ### Some base functions.
 
-comm.length <- function(x, comm = .SPMD.CT$comm){
+comm.length <- function(x, comm = .pbd_env$SPMD.CT$comm){
   if(! comm.all(is.vector(x), comm = comm)){
     comm.stop("x should be a vector.", comm = comm)
   }
@@ -9,13 +9,13 @@ comm.length <- function(x, comm = .SPMD.CT$comm){
   ret
 } # End of comm.length().
 
-comm.sum <- function(..., na.rm = TRUE, comm = .SPMD.CT$comm){
+comm.sum <- function(..., na.rm = TRUE, comm = .pbd_env$SPMD.CT$comm){
   tmp <- sum(..., na.rm = na.rm)
   ret <- allreduce(tmp, op = "sum", comm = comm)
   ret
 } # End of comm.sum().
 
-comm.mean <- function(x, na.rm = TRUE, comm = .SPMD.CT$comm){
+comm.mean <- function(x, na.rm = TRUE, comm = .pbd_env$SPMD.CT$comm){
   if(! comm.all(is.vector(x), comm = comm)){
     comm.stop("x should be a vector.", comm = comm)
   }
@@ -30,7 +30,7 @@ comm.mean <- function(x, na.rm = TRUE, comm = .SPMD.CT$comm){
   ret
 } # End of comm.mean().
 
-comm.var <- function(x, na.rm = TRUE, comm = .SPMD.CT$comm){
+comm.var <- function(x, na.rm = TRUE, comm = .pbd_env$SPMD.CT$comm){
   if(! comm.all(is.vector(x), comm = comm)){
     comm.stop("x should be a vector.", comm = comm)
   }
@@ -47,7 +47,7 @@ comm.var <- function(x, na.rm = TRUE, comm = .SPMD.CT$comm){
   ret
 } # End of comm.var().
 
-comm.sd <- function(x, na.rm = TRUE, comm = .SPMD.CT$comm){
+comm.sd <- function(x, na.rm = TRUE, comm = .pbd_env$SPMD.CT$comm){
   ret <- comm.var(x, na.rm = na.rm, comm = comm)
   ret <- sqrt(ret)
   ret
