@@ -1,6 +1,7 @@
 spmd.comm.spawn <- function(worker, worker.arg, n.workers,
-    info = .SPMD.CT$info, rank.source = .SPMD.CT$rank.source,
-    intercomm = .SPMD.CT$intercomm){
+    info = .pbd_env$SPMD.CT$info,
+    rank.source = .pbd_env$SPMD.CT$rank.source,
+    intercomm = .pbd_env$SPMD.CT$intercomm){
   if(! is.loaded("spmd_comm_spawn", PACKAGE = "pbdMPI")){
     stop("spmd_comm_spawn is not supported.")
   }
