@@ -1,6 +1,6 @@
 ### SHELL> mpiexec -np 2 Rscript --vanilla [...].r
 
-library(pbdMPI, quietly = TRUE)
+suppressMessages(library(pbdMPI, quietly = TRUE))
 init()
 .comm.size <- comm.size()
 .comm.rank <- comm.rank()
@@ -34,4 +34,3 @@ y <- allreduce(as.double(x), op = "min")
 comm.print(y[N - (1:5)])
 
 finalize()
-
